@@ -41,6 +41,8 @@
 
 #include "data/splash/splash_screen.xpm"
 #include "data/splash/splash_holidays.xpm"
+#include "data/splash/splash_screen_x2.xpm"
+#include "data/splash/splash_holidays_x2.xpm"
 #include "KisDocument.h"
 #include "kis_splash_screen.h"
 #include "KisPart.h"
@@ -311,10 +313,10 @@ extern "C" int main(int argc, char **argv)
         QWidget *splash = 0;
         if (currentDate > QDate(currentDate.year(), 12, 4) ||
                 currentDate < QDate(currentDate.year(), 1, 9)) {
-            splash = new KisSplashScreen(app.applicationVersion(), QPixmap(splash_holidays_xpm));
+            splash = new KisSplashScreen(app.applicationVersion(), QPixmap(splash_holidays_xpm), QPixmap(splash_holidays_x2_xpm));
         }
         else {
-            splash = new KisSplashScreen(app.applicationVersion(), QPixmap(splash_screen_xpm));
+            splash = new KisSplashScreen(app.applicationVersion(), QPixmap(splash_screen_xpm), QPixmap(splash_screen_x2_xpm));
         }
 
         app.setSplashScreen(splash);
