@@ -34,7 +34,8 @@
 #include <KoPathPointData.h>
 #include <KoPathPointMergeCommand.h>
 #include <KoShapePaintingContext.h>
-#include <KoStrokeConfigWidget.h>
+#include <widgets/KoStrokeConfigWidget.h>
+#include <KisHandlePainterHelper.h>
 
 #include <klocalizedstring.h>
 
@@ -64,6 +65,7 @@ KoPencilTool::KoPencilTool(KoCanvasBase *canvas)
     , m_existingStartPoint(0)
     , m_existingEndPoint(0)
     , m_hoveredPoint(0)
+    , m_strokeWidget(0)
 {
 }
 
@@ -93,15 +95,11 @@ void KoPencilTool::paint(QPainter &painter, const KoViewConverter &converter)
     }
 
     if (m_hoveredPoint) {
-        painter.save();
-        painter.setTransform(m_hoveredPoint->parent()->absoluteTransformation(&converter), true);
-        KoShape::applyConversion(painter, converter);
+        KisHandlePainterHelper helper =
+            KoShape::createHandlePainterHelper(&painter, m_hoveredPoint->parent(), converter, handleRadius());
 
-        painter.setPen(Qt::blue);      //TODO make configurable
-        painter.setBrush(Qt::white);   //TODO make configurable
-        m_hoveredPoint->paint(painter, handleRadius(), KoPathPoint::Node);
-
-        painter.restore();
+        helper.setHandleStyle(KisHandleStyle::primarySelection());
+        m_hoveredPoint->paint(helper, KoPathPoint::Node);
     }
 }
 
@@ -111,7 +109,9 @@ void KoPencilTool::repaintDecorations()
 
 void KoPencilTool::mousePressEvent(KoPointerEvent *event)
 {
-    if (! m_shape) {
+    KoShapeStrokeSP stroke = createStroke();
+
+    if (!m_shape && stroke && stroke->isVisible()) {
         m_shape = new KoPathShape();
         m_shape->setShapeId(KoPathShapeId);
         m_shape->setStroke(createStroke());
@@ -178,11 +178,17 @@ void KoPencilTool::keyPressEvent(QKeyEvent *event)
     }
 }
 
-void KoPencilTool::activate(ToolActivation, const QSet<KoShape*> &)
+void KoPencilTool::activate(ToolActivation activation, const QSet<KoShape*> &shapes)
 {
+    KoToolBase::activate(activation, shapes);
+
     m_points.clear();
     m_close = false;
-    useCursor(Qt::ArrowCursor);
+    slotUpdatePencilCursor();
+
+    if (m_strokeWidget) {
+        m_strokeWidget->activate();
+    }
 }
 
 void KoPencilTool::deactivate()
@@ -193,6 +199,18 @@ void KoPencilTool::deactivate()
     m_existingStartPoint = 0;
     m_existingEndPoint = 0;
     m_hoveredPoint = 0;
+
+    if (m_strokeWidget) {
+        m_strokeWidget->deactivate();
+    }
+
+    KoToolBase::deactivate();
+}
+
+void KoPencilTool::slotUpdatePencilCursor()
+{
+    KoShapeStrokeSP stroke = createStroke();
+    useCursor((stroke && stroke->isVisible()) ? Qt::ArrowCursor : Qt::ForbiddenCursor);
 }
 
 void KoPencilTool::addPoint(const QPointF & point)
@@ -353,9 +371,13 @@ QList<QPointer<QWidget> > KoPencilTool::createOptionWidgets()
     optionWidget->setWindowTitle(i18n("Pencil"));
     widgets.append(optionWidget);
 
-    m_strokeWidget = new KoStrokeConfigWidget(0);
+    m_strokeWidget = new KoStrokeConfigWidget(canvas(), 0);
+    m_strokeWidget->setNoSelectionTrackingMode(true);
     m_strokeWidget->setWindowTitle(i18n("Line"));
-    m_strokeWidget->setCanvas(canvas());
+    connect(m_strokeWidget, SIGNAL(sigStrokeChanged()), SLOT(slotUpdatePencilCursor()));
+    if (isActivated()) {
+        m_strokeWidget->activate();
+    }
     widgets.append(m_strokeWidget);
     return widgets;
 }
@@ -378,7 +400,7 @@ void KoPencilTool::addPathShape(KoPathShape* path, bool closePath)
         }
     }
 
-    KUndo2Command * cmd = canvas()->shapeController()->addShape(path);
+    KUndo2Command * cmd = canvas()->shapeController()->addShape(path, 0);
     if (cmd) {
         KoSelection *selection = canvas()->shapeManager()->selection();
         selection->deselectAll();
@@ -417,9 +439,9 @@ void KoPencilTool::setDelta(double delta)
         m_combineAngle = delta;
 }
 
-KoShapeStroke* KoPencilTool::createStroke()
+KoShapeStrokeSP KoPencilTool::createStroke()
 {
-    KoShapeStroke *stroke = 0;
+    KoShapeStrokeSP stroke;
     if (m_strokeWidget) {
         stroke = m_strokeWidget->createShapeStroke();
     }
