@@ -243,14 +243,16 @@ QString KisImageConfig::swapDir(bool requestDefault)
     // furthermore, this is just a default and swapDir can always be configured
     // to another location.
 
-    QString swap = QDir::homePath();
+    QString swap = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation) + "/swap";
 #else
     QString swap = QDir::tempPath();
 #endif
-    QString configuredSwap = !requestDefault ?
-            m_config.readEntry("swaplocation", swap) : swap;
-    if (configuredSwap.isEmpty()) {
-        configuredSwap = swap;
+    if (requestDefault) {
+       return swap;
+    }
+    QString configuredSwap = m_config.readEntry("swaplocation", swap);
+    if (!configuredSwap.isEmpty()) {
+        swap = configuredSwap;
     }
     return swap;
 }
