@@ -25,9 +25,11 @@
 #include "spray_brush.h"
 #include "kis_spray_paintop_settings.h"
 #include "kis_brush_option.h"
+#include <kis_airbrush_option.h>
 #include <kis_pressure_rotation_option.h>
 #include <kis_pressure_opacity_option.h>
 #include <kis_pressure_size_option.h>
+#include <kis_pressure_rate_option.h>
 
 class KisPainter;
 
@@ -38,9 +40,18 @@ class KisSprayPaintOp : public KisPaintOp
 public:
 
     KisSprayPaintOp(const KisPaintOpSettingsSP settings, KisPainter * painter, KisNodeSP node, KisImageSP image);
-    ~KisSprayPaintOp();
+    ~KisSprayPaintOp() override;
 
-    KisSpacingInformation paintAt(const KisPaintInformation& info);
+protected:
+
+    KisSpacingInformation paintAt(const KisPaintInformation& info) override;
+
+    KisSpacingInformation updateSpacingImpl(const KisPaintInformation &info) const override;
+
+    KisTimingInformation updateTimingImpl(const KisPaintInformation &info) const override;
+
+private:
+    KisSpacingInformation computeSpacing(const KisPaintInformation &info, qreal lodScale) const;
 
 private:
     KisShapeProperties m_shapeProperties;
@@ -49,15 +60,15 @@ private:
     KisColorProperties m_colorProperties;
     KisBrushOption m_brushOption;
 
-    KisSprayPaintOpSettingsSP m_settings;
-
     KisPaintDeviceSP m_dab;
     SprayBrush m_sprayBrush;
     qreal m_xSpacing, m_ySpacing, m_spacing;
     bool m_isPresetValid;
+    KisAirbrushOption m_airbrushOption;
     KisPressureRotationOption m_rotationOption;
     KisPressureSizeOption m_sizeOption;
     KisPressureOpacityOption m_opacityOption;
+    KisPressureRateOption m_rateOption;
     KisNodeSP m_node;
 };
 
