@@ -30,6 +30,7 @@
 #include <QVector2D>
 #include <QVector3D>
 #include <QButtonGroup>
+#include <QPointer>
 
 #include <QKeySequence>
 
@@ -40,16 +41,13 @@
 #include <kis_types.h>
 #include <flake/kis_node_shape.h>
 #include <kis_tool.h>
+#include <kis_canvas2.h>
 
 #include "tool_transform_args.h"
 #include "tool_transform_changes_tracker.h"
 #include "kis_tool_transform_config_widget.h"
 #include "transform_transaction_properties.h"
 
-
-
-class KisCanvas2;
-
 class QTouchEvent;
 class KisTransformStrategyBase;
 class KisWarpTransformStrategy;
@@ -127,13 +125,23 @@ public:
     KisToolTransform(KoCanvasBase * canvas);
     ~KisToolTransform() override;
 
+    /**
+     * @brief wantsAutoScroll
+     * reimplemented from KoToolBase
+     * there's an issue where autoscrolling with this tool never makes the
+     * stroke end, so we return false here so that users don't get stuck with
+     * the tool. See bug 362659
+     * @return false
+     */
+    bool wantsAutoScroll() const {
+        return false;
+    }
+
     QWidget* createOptionWidget() override;
 
     void mousePressEvent(KoPointerEvent *e) override;
     void mouseMoveEvent(KoPointerEvent *e) override;
     void mouseReleaseEvent(KoPointerEvent *e) override;
-    void touchEvent(QTouchEvent *event) override;
-
     void beginActionImpl(KoPointerEvent *event, bool usePrimaryAction, KisTool::AlternateAction action);
     void continueActionImpl(KoPointerEvent *event, bool usePrimaryAction, KisTool::AlternateAction action);
     void endActionImpl(KoPointerEvent *event, bool usePrimaryAction, KisTool::AlternateAction action);
@@ -171,8 +179,6 @@ public:
     double warpFlexibility() const;
     int warpPointDensity() const;
 
-    bool wantsTouch() const override { return true; }
-
 public Q_SLOTS:
     void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
     void deactivate() override;
@@ -220,8 +226,10 @@ public Q_SLOTS:
     void imageTooBigRequested(bool value);
 
 private:
-    bool clearDevices(KisNodeSP node, bool recursive);
-    void transformDevices(KisNodeSP node, bool recursive);
+    QList<KisNodeSP> fetchNodesList(ToolTransformArgs::TransformMode mode, KisNodeSP root, bool recursive);
+
+    bool clearDevices(const QList<KisNodeSP> &nodes);
+    void transformClearedDevices();
 
     void startStroke(ToolTransformArgs::TransformMode mode, bool forceReset);
     void endStroke();
@@ -246,6 +254,8 @@ private:
     void updateSelectionPath();
     void updateApplyResetAvailability();
 
+    void forceRepaintDelayedLayers(KisNodeSP root);
+
 private:
     ToolTransformArgs m_currentArgs;
 
@@ -277,7 +287,7 @@ private:
     QPainterPath m_selectionPath; // original (unscaled) selection outline, used for painting decorations
 
     KisToolTransformConfigWidget *m_optionsWidget;
-    KisCanvas2 *m_canvas;
+    QPointer<KisCanvas2> m_canvas;
 
     TransformTransactionProperties m_transaction;
     TransformChangesTracker m_changesTracker;
